local addonName, addon = ...
addon.L = addon.L or {} --setup localization
local L = setmetatable(addon.L, {__index = function(t,i) return i end} )

local defaults = {
	global = {
		["enabled"] = true,
		[3] = { --Normal mode combos:			
			["BlackBlueYellow"] = L['Yellow'],
			["BlackGreenRed"] = L['Green'],
			["BlackPurpleRed"] = L['Purple'],
			["BlueGreenPurple"] = L['Purple'],
			["BluePurpleYellow"] = L['Purple'],
			["GreenRedYellow"] = L['Green'],
		},
		[4] = { --Heroic mode combos (don't know which are actually possible so just listing them all, and priority is just a best-guess):
			["BlackBlueGreenPurple"] = L['Purple'],
			["BlackBlueGreenRed"] = L['Green'],
			["BlackBlueGreenYellow"] = L['Green'],
			["BlackBluePurpleRed"] = L['Purple'],
			["BlackBluePurpleYellow"] = L['Purple'],
			["BlackBlueRedYellow"] = L['Yellow'],
			["BlackGreenPurpleRed"] = L['Green'],
			["BlackGreenPurpleYellow"] = L['Purple'],
			["BlackGreenRedYellow"] = L['Green'],
			["BlackPurpleRedYellow"] = L['Purple'],
			["BlueGreenPurpleRed"] = L['Green'],
			["BlueGreenPurpleYellow"] = L['Purple'],
			["BlueGreenRedYellow"] = L['Green'],
			["BluePurpleRedYellow"] = L['Purple'],
			["GreenPurpleRedYellow"] = L['Green'],
		},
	},
}

local optionsTable = {
    name = addonName,
    handler = addon,
    type = 'group',
    args = {
		enable = {
			name = L['Enable'],
			type = 'toggle',
			set = function(_, enabled)
				addon.db.global.enabled = enabled
				if enabled then
					addon:Enable()
				else
					addon:Disable()
				end
			end,
			get = function() return addon.db.global.enabled end,
		},
		reset = {
			name = L['Restore Defaults'],
			desc = L['Restore all combinations to default kill targets.'],
			type = 'execute',
			func = function()
				addon.db:ResetDB()
			end,
		},
		normal = {
			type = 'group',
			name = L['Normal Mode'],
			desc = L['Setup priorities for normal mode combinations here.'],
			order = 1,
			args = {
				Header = {
					type = 'header',
					name = L['Normal Mode Globule Combinations'],
					order = 0,
				},
				BlueGreenPurple = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'],
					set = function(_, value)
						addon.db.global[3].BlueGreenPurple = value
					end,
					get = function() return addon.db.global[3].BlueGreenPurple end,
				},
				GreenRedYellow = {
					type = 'input',
					name = "|cff00ff00"..L['Green'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[3].GreenRedYellow = value
					end,
					get = function() return addon.db.global[3].GreenRedYellow end,
				},
				BlackGreenRed = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff00ff00"..L['Green'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[3].BlackGreenRed = value
					end,
					get = function() return addon.db.global[3].BlackGreenRed end,
				},
				BluePurpleYellow = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cffff00ff"..L['Purple'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[3].BluePurpleYellow = value
					end,
					get = function() return addon.db.global[3].BluePurpleYellow end,
				},
				BlackPurpleRed = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[3].BlackPurpleRed = value
					end,
					get = function() return addon.db.global[3].BlackPurpleRed end,
				},
				BlackBlueYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[3].BlackBlueYellow = value
					end,
					get = function() return addon.db.global[3].BlackBlueYellow end,
				},
			},
		},
		heroic = {
			type = 'group',
			name = L['Heroic Mode'],
			desc = L['Setup priorities for heroic mode combinations here.'],
			order = 2,
			args = {
				Header = {
					type = 'header',
					name = L['Heroic Mode Globule Combinations'],
					order = 0,
				},
				Disclaimer = {
					type = 'description',
					order = 1,
					name = L['If heroic mode is like normal mode, only some of these combinations are actually possible. Unlike normal mode, I do not yet know which are/aren\'t possible, so I have included all 15 possible combinations. Globule detection in heroic mode should work, but is completely untested.'],
				},
				BlackBlueGreenPurple = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'],
					set = function(_, value)
						addon.db.global[4].BlackBlueGreenPurple = value
					end,
					get = function() return addon.db.global[4].BlackBlueGreenPurple end,
				},
				BlackBlueGreenRed = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[4].BlackBlueGreenRed = value
					end,
					get = function() return addon.db.global[4].BlackBlueGreenRed end,
				},
				BlackBlueGreenYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackBlueGreenYellow = value
					end,
					get = function() return addon.db.global[4].BlackBlueGreenYellow end,
				},
				BlackBluePurpleRed = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[4].BlackBluePurpleRed = value
					end,
					get = function() return addon.db.global[4].BlackBluePurpleRed end,
				},
				BlackBluePurpleYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cffff00ff"..L['Purple'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackBluePurpleYellow = value
					end,
					get = function() return addon.db.global[4].BlackBluePurpleYellow end,
				},
				BlackBlueRedYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff0000ff"..L['Blue'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackBlueRedYellow = value
					end,
					get = function() return addon.db.global[4].BlackBlueRedYellow end,
				},
				BlackGreenPurpleRed = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[4].BlackGreenPurpleRed = value
					end,
					get = function() return addon.db.global[4].BlackGreenPurpleRed end,
				},
				BlackGreenPurpleYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackGreenPurpleYellow = value
					end,
					get = function() return addon.db.global[4].BlackGreenPurpleYellow end,
				},
				BlackGreenRedYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cff00ff00"..L['Green'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackGreenRedYellow = value
					end,
					get = function() return addon.db.global[4].BlackGreenRedYellow end,
				},
				BlackPurpleRedYellow = {
					type = 'input',
					name = "|cff000000"..L['Black'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlackPurpleRedYellow = value
					end,
					get = function() return addon.db.global[4].BlackPurpleRedYellow end,
				},
				BlueGreenPurpleRed = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'],
					set = function(_, value)
						addon.db.global[4].BlueGreenPurpleRed = value
					end,
					get = function() return addon.db.global[4].BlueGreenPurpleRed end,
				},
				BlueGreenPurpleYellow = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlueGreenPurpleYellow = value
					end,
					get = function() return addon.db.global[4].BlueGreenPurpleYellow end,
				},
				BlueGreenRedYellow = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cff00ff00"..L['Green'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BlueGreenRedYellow = value
					end,
					get = function() return addon.db.global[4].BlueGreenRedYellow end,
				},
				BluePurpleRedYellow = {
					type = 'input',
					name = "|cff0000ff"..L['Blue'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].BluePurpleRedYellow = value
					end,
					get = function() return addon.db.global[4].BluePurpleRedYellow end,
				},
				GreenPurpleRedYellow = {
					type = 'input',
					name = "|cff00ff00"..L['Green'].." |cffff00ff"..L['Purple'].." |cffff0000"..L['Red'].." |cffffff00"..L['Yellow'],
					set = function(_, value)
						addon.db.global[4].GreenPurpleRedYellow = value
					end,
					get = function() return addon.db.global[4].GreenPurpleRedYellow end,
				},
			},
		},
    },
}

function addon:SetupDB()
	self.db = LibStub("AceDB-3.0"):New(addonName.."DB", defaults)
end

function addon:SetupOptions()
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, optionsTable)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName)
end